* Output options: all can be turned on/off by adding or removing the NO:
  page number, date, centering, or page breaks, page length and width; 
OPTIONS nonumber nodate nocenter formdlim=' ' pagesize=MAX linesize=MAX; 
* Eliminate SAS default titles and table names in log (TRACE ON to show);
TITLE; ODS TRACE OFF;

******************************************************************************************;
******         Measuring Individual Differences in Responses to                    *******;
******          Date-Rape Vignette Using Latent Variable Models                    *******;
******           Tuliao, Hoffman, & McChargue, in press                            *******;
******************************************************************************************;

* Defining global variable for location of SPSS file used in examples -- CHANGE THIS;
%LET example= C:\Dropbox\Vignette_Example;

* Import SPSS data file into SAS;
PROC IMPORT DATAFILE="&example.\Vignette_SPSS_Data.sav" DBMS=SAV 
     OUT=work.example REPLACE; RUN;

*******************************************************************************************;
******               Exporting Data for Use in Mplus                               ********;
*******************************************************************************************;

/* Fill in missing values with -9999;
DATA work.Mplus; SET work.example; 
	FORMAT _ALL_; * Remove value labels from SPSS;
     ARRAY avar(20) Sample  C_DV01--C_DV18 StopPt;
     DO i=1 TO 20; IF avar(i)=. THEN avar(i)=-9999; END; 
     DROP i; 
RUN;
* Export to .csv for use in Mplus;
PROC EXPORT DATA=work.Mplus OUTFILE= "&example.\Vignette.csv" 
     DBMS=CSV REPLACE; PUTNAMES=NO; RUN; */

*******************************************************************************************;
******     Conventional Ways of Analyzing Date-Rape Vignette Data                  ********;
******                       Between Groups ANOVA                                  ********;
*******************************************************************************************;

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\Vignette_SAS_Log&Output.txt" 
             LOG=  "&example.\Vignette_SAS_Log&Output.txt"; RUN;

TITLE1 "Supplemental Material Equation 1: BG ANOVA Model on Stopping Point";
PROC MIXED DATA=work.example NOCLPRINT NOITPRINT METHOD=REML;
     CLASS sample;
     MODEL StopPt = sample / SOLUTION DDFM=BW;  
     LSMEANS sample;
RUN; TITLE1;

TITLE1 "Supplemental Material Equation 1: BG ANOVA Model on E06";
PROC MIXED DATA=work.example NOCLPRINT NOITPRINT METHOD=REML;
     CLASS sample;
     MODEL C_DV06 = sample / SOLUTION DDFM=BW;  
     LSMEANS sample;
RUN; TITLE1;

*******************************************************************************************;
******     Stacking Data and Creating Piecewise Slopes for Event Phases            ********;
******                        (see Table 2)                                        ********;
*******************************************************************************************;

* Reshape the data from a wide format to a long format to run MLM in SAS;
DATA work.example_stacked; SET work.example;
    event=1;  Comfort=C_DV01; OUTPUT;    
    event=2;  Comfort=C_DV02; OUTPUT;
    event=3;  Comfort=C_DV03; OUTPUT;
    event=4;  Comfort=C_DV04; OUTPUT;
    event=5;  Comfort=C_DV05; OUTPUT;
    event=6;  Comfort=C_DV06; OUTPUT;
    event=7;  Comfort=C_DV07; OUTPUT;
    event=8;  Comfort=C_DV08; OUTPUT;
    event=9;  Comfort=C_DV09; OUTPUT;
    event=10; Comfort=C_DV10; OUTPUT;
    event=11; Comfort=C_DV11; OUTPUT;
    event=12; Comfort=C_DV12; OUTPUT;
    event=13; Comfort=C_DV13; OUTPUT;
    event=14; Comfort=C_DV14; OUTPUT;
    event=15; Comfort=C_DV15; OUTPUT;
    event=16; Comfort=C_DV16; OUTPUT;
    event=17; Comfort=C_DV17; OUTPUT;
    event=18; Comfort=C_DV18; OUTPUT;       
    LABEL   event=   "event: vignette time"
            Comfort= "DV: Comfort (1-5)";
    DROP C_DV01--C_DV18; * Remove multivariate outcomes;
RUN;

* Create piecewise slopes for event phases;
DATA work.example_stacked; SET work.example_stacked;
     IF event= 1 THEN DO; phase1 = 0; phase2 = 0; phase3 = 0; phase4 = 0; phase5 = 0; phase6 = 0; phase7 = 0; phase8 = 0; END;
ELSE IF event= 2 THEN DO; phase1 = 1; phase2 = 0; phase3 = 0; phase4 = 0; phase5 = 0; phase6 = 0; phase7 = 0; phase8 = 0; END;  
ELSE IF event= 3 THEN DO; phase1 = 2; phase2 = 0; phase3 = 0; phase4 = 0; phase5 = 0; phase6 = 0; phase7 = 0; phase8 = 0; END;
ELSE IF event= 4 THEN DO; phase1 = 3; phase2 = 0; phase3 = 0; phase4 = 0; phase5 = 0; phase6 = 0; phase7 = 0; phase8 = 0; END;
ELSE IF event= 5 THEN DO; phase1 = 4; phase2 = 0; phase3 = 0; phase4 = 0; phase5 = 0; phase6 = 0; phase7 = 0; phase8 = 0; END;
ELSE IF event= 6 THEN DO; phase1 = 4; phase2 = 1; phase3 = 0; phase4 = 0; phase5 = 0; phase6 = 0; phase7 = 0; phase8 = 0; END;
ELSE IF event= 7 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 0; phase5 = 0; phase6 = 0; phase7 = 0; phase8 = 0; END;
ELSE IF event= 8 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 1; phase5 = 0; phase6 = 0; phase7 = 0; phase8 = 0; END;
ELSE IF event= 9 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 2; phase5 = 0; phase6 = 0; phase7 = 0; phase8 = 0; END;
ELSE IF event=10 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 2; phase5 = 1; phase6 = 0; phase7 = 0; phase8 = 0; END;
ELSE IF event=11 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 2; phase5 = 2; phase6 = 0; phase7 = 0; phase8 = 0; END;
ELSE IF event=12 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 2; phase5 = 2; phase6 = 1; phase7 = 0; phase8 = 0; END;
ELSE IF event=13 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 2; phase5 = 2; phase6 = 1; phase7 = 1; phase8 = 0; END;
ELSE IF event=14 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 2; phase5 = 2; phase6 = 1; phase7 = 2; phase8 = 0; END;
ELSE IF event=15 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 2; phase5 = 2; phase6 = 1; phase7 = 2; phase8 = 1; END;
ELSE IF event=16 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 2; phase5 = 2; phase6 = 1; phase7 = 2; phase8 = 2; END;
ELSE IF event=17 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 2; phase5 = 2; phase6 = 1; phase7 = 2; phase8 = 3; END;
ELSE IF event=18 THEN DO; phase1 = 4; phase2 = 1; phase3 = 1; phase4 = 2; phase5 = 2; phase6 = 1; phase7 = 2; phase8 = 4; END;
RUN;

*******************************************************************************************;
******                       Multilevel Models                                     ********;
*******************************************************************************************;

TITLE1 "Saturated Means, Unstructured Variance Model on Comfort at 18 Events";
TITLE2 "Use to make Figure 1";
PROC MIXED DATA=work.example_stacked NOCLPRINT NOITPRINT COVTEST IC METHOD=ML;
     CLASS PersonID event sample;
     MODEL comfort = event / SOLUTION DDFM=BW;
     REPEATED event / R RCORR TYPE=UN SUBJECT=PersonID; 
     LSMEANS event;
RUN; TITLE1; TITLE2;

TITLE1 "Supplemental Material Equation 2: Univariate RM ANOVA Model on Comfort at 18 events";
PROC MIXED DATA=work.example_stacked NOCLPRINT NOITPRINT COVTEST IC METHOD=REML;
     CLASS PersonID event sample;
     MODEL comfort = event sample event*sample / SOLUTION DDFM=BW;
     REPEATED event / TYPE=CS SUBJECT=PersonID; 
     LSMEANS event sample event*sample;
RUN; TITLE1;

TITLE1 "Supplemental Material Equation 3: Empty Means, Random Intercept Model";
PROC MIXED DATA=work.example_stacked NOCLPRINT NOITPRINT COVTEST IC METHOD=ML;
     CLASS PersonID event;
     MODEL comfort =  / NOTEST SOLUTION DDFM=Satterthwaite; 
     RANDOM INTERCEPT / TYPE=UN SUBJECT=PersonID VCORR; * VCORR provides ICC;
     REPEATED event   / TYPE=VC SUBJECT=PersonID;
RUN; TITLE1;

TITLE1 "Supplemental Material Equation 4: Random Intercept, Fixed Piecewise Slopes Model";
PROC MIXED DATA=work.example_stacked NOCLPRINT NOITPRINT COVTEST IC METHOD=ML;
     CLASS PersonID event;
     MODEL comfort = phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 phase8*phase8
                      / NOTEST SOLUTION DDFM=Satterthwaite; 
     RANDOM INTERCEPT / TYPE=UN SUBJECT=PersonID;
     REPEATED event   / TYPE=VC SUBJECT=PersonID;
RUN; TITLE1;

TITLE1 "Supplemental Material Equation 5: Random Piecewise Slopes Model";
PROC MIXED DATA=work.example_stacked NOCLPRINT NOITPRINT COVTEST IC METHOD=ML;
     CLASS PersonID event;
     MODEL comfort = phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 phase8*phase8
                     / NOTEST SOLUTION DDFM=Satterthwaite;
     RANDOM INTERCEPT phase1 phase2 phase3 phase4 phase5 phase6 phase8 
                     / G GCORR TYPE=UN SUBJECT=PersonID;    
     REPEATED event / TYPE=VC SUBJECT=PersonID;
RUN; TITLE1;

* Creating new varibles needed for revised random slope model;
DATA work.example_stacked; SET work.example_stacked;
     IF event=2 THEN event02=1; ELSE event02=0;                  * To allow mean increment at event2;
     IF event IN(9,12,15,16,17,18) THEN resAup=1; ELSE resAup=0; * To allow different residual variances;
	IF event IN(10,11,13,14) THEN resAup=2;                     * Residual variance differs to allow random int;
     IF event IN(13,14) THEN rand1314=1; ELSE rand1314=0;        * To allow extra residual covariance for 13-14;
     IF event IN(10,11) THEN rand1011=1; ELSE rand1011=0;        * To allow extra residual covariance for 10-11;

TITLE1 "Supplemental Material Equation 6: Revised Random Piecewise Slopes Model";
TITLE2 "Residual covariances via random intercepts do not match Mplus, but are close";
PROC MIXED DATA=work.example_stacked NOCLPRINT NOITPRINT COVTEST IC METHOD=ML;
     CLASS PersonID event resAup;
     MODEL comfort = phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 phase8*phase8 event02 
                    / NOTEST SOLUTION DDFM=Satterthwaite;   
     RANDOM INTERCEPT phase1 phase2 phase3 phase4 phase5 phase6 phase8 
                     / V GCORR TYPE=UN SUBJECT=PersonID;
     RANDOM rand1314 rand1011 / TYPE=VC SUBJECT=PersonID;  * Add extra covariances among residuals;
     REPEATED / SUBJECT=PersonID GROUP=resAup; * Add different residual variance for those events;
     ESTIMATE "Slope difference between phase 1 and 2" phase1 -1 phase2 1;
RUN; TITLE1; TITLE2;

TITLE1 "Supplemental Material Equation 7: Sample Predicting Random Piecewise Slopes";
TITLE2 "Residual covariances via random intercepts do not match Mplus, but are close";
TITLE3 "U.S. sample (reference group=0), Philippines sample (comparison group=1)";
TITLE4 "Stopping point is not included";
PROC MIXED DATA=work.example_stacked NOCLPRINT NOITPRINT COVTEST IC METHOD=ML;
     CLASS PersonID event resAup;
     MODEL comfort = phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 phase8*phase8 event02
                     sample sample*phase1 sample*phase2 sample*phase3 sample*phase4 
                     sample*phase5 sample*phase6 sample*phase8 / NOTEST SOLUTION DDFM=Satterthwaite;    
     RANDOM INTERCEPT phase1 phase2 phase3 phase4 phase5 phase6 phase8 / GCORR TYPE=UN SUBJECT=PersonID;
     RANDOM rand1314 rand1011 / TYPE=VC SUBJECT=PersonID;  * Add extra covariances among residuals;
     REPEATED / SUBJECT=PersonID GROUP=resAup; * Add different residual variance for those events;
     ESTIMATE "PH Intercept"     intercept 1 sample 1;
     ESTIMATE "PH phase 1 slope" phase1 1 sample*phase1 1;
     ESTIMATE "PH phase 2 slope" phase2 1 sample*phase2 1;
     ESTIMATE "PH phase 3 slope" phase3 1 sample*phase3 1;
     ESTIMATE "PH phase 4 slope" phase4 1 sample*phase4 1;
     ESTIMATE "PH phase 5 slope" phase5 1 sample*phase5 1;
     ESTIMATE "PH phase 6 slope" phase6 1 sample*phase6 1;
     ESTIMATE "PH phase 8 slope" phase8 1 sample*phase8 1;  
RUN; TITLE1; TITLE2; TITLE3; TITLE4;

* Close file;
PROC PRINTTO; RUN;
