* Encoding: UTF-8.

******************************************************************************************.
******         Measuring Individual Differences in Responses to                    *******.
******          Date-Rape Vignette Using Latent Variable Models                    *******.
******           Tuliao, Hoffman, & McChargue, in press                            *******.
******************************************************************************************.

* Define location of SPSS data file used in examples -- CHANGE THIS.
FILE HANDLE example /NAME = "C:\Dropbox\Vignette_Example".
GET FILE = 'example/Vignette_SPSS_Data.sav'.
DATASET NAME example WINDOW=FRONT.
EXECUTE.

*******************************************************************************************.
******               Exporting Data for Use in Mplus                               ********.
*******************************************************************************************.

* Fill in missing values with -9999.
*DATASET ACTIVATE example.
*RECODE Sample StopPt C_DV01 TO C_DV18 (SYSMIS = -9999) (ELSE=COPY).
* Export to csv for use in Mplus.
*SAVE TRANSLATE OUTFILE='example/Vignette.csv' 
*     /TYPE=CSV /REPLACE.

*******************************************************************************************.
******     Conventional Ways of Analyzing Date-Rape Vignette Data                  ********.
******                       Between Groups ANOVA                                  ********.
*******************************************************************************************.

DATASET ACTIVATE example.
ECHO 'Supplemental Material Equation 1: BG ANOVA Model on Stopping Point'.
MIXED StopPt BY sample 
  /FIXED   = sample 
  /METHOD  = REML 
  /PRINT   = SOLUTION
  /EMMEANS = TABLES(sample).

ECHO 'Supplemental Material Equation 1: BG ANOVA Model on E06'.
MIXED C_DV06 BY sample 
  /FIXED   = sample 
  /METHOD  = REML 
  /PRINT   = SOLUTION
  /EMMEANS = TABLES(sample).

*******************************************************************************************.
******     Stacking Data and Creating Piecewise Slopes for Event Phases            ********.
******                        (see Table 2)                                        ********.
*******************************************************************************************.

* Reshape the data from a wide format to a long format to run MLM in SPSS.
VARSTOCASES
  /MAKE Comfort FROM C_DV01 TO C_DV18
  /INDEX = Event
  /DROP C_DV01 TO C_DV18.
VARIABLE LABELS Event 'Vignette Event' Comfort 'Comfort Outcome'.
DATASET NAME example_stacked WINDOW=FRONT.

* Create piecewise slopes for event phases.
DO IF (Event=1).
   DO REPEAT phase=phase1 to phase8
      /value1 = 0 0 0 0 0 0 0 0.
   COMPUTE phase=value1.
   END REPEAT.
ELSE IF (Event=2).
   DO REPEAT phase=phase1 to phase8
      /value2 = 1 0 0 0 0 0 0 0.
   COMPUTE phase=value2.
   END REPEAT.
ELSE IF (Event=3).
   DO REPEAT phase=phase1 to phase8
      /value3 = 2 0 0 0 0 0 0 0.
   COMPUTE phase=value3.
   END REPEAT.
ELSE IF (Event=4).
   DO REPEAT phase=phase1 to phase8
      /value4 = 3 0 0 0 0 0 0 0.
   COMPUTE phase=value4.
   END REPEAT.
ELSE IF (Event=5).
   DO REPEAT phase=phase1 to phase8
      /value5 = 4 0 0 0 0 0 0 0.
   COMPUTE phase=value5.
   END REPEAT.
ELSE IF (Event=6).
   DO REPEAT phase=phase1 to phase8
      /value6 = 4 1 0 0 0 0 0 0.
   COMPUTE phase=value6.
   END REPEAT.
ELSE IF (Event=7).
      DO REPEAT phase=phase1 to phase8
      /value7 = 4 1 1 0 0 0 0 0.
   COMPUTE phase=value7.
   END REPEAT.
ELSE IF (Event=8).
   DO REPEAT phase=phase1 to phase8
      /value8 = 4 1 1 1 0 0 0 0.
   COMPUTE phase=value8.
   END REPEAT.
ELSE IF (Event=9).
   DO REPEAT phase=phase1 to phase8
      /value9 = 4 1 1 2 0 0 0 0.
   COMPUTE phase=value9.
   END REPEAT.
ELSE IF (Event=10).
   DO REPEAT phase=phase1 to phase8
      /value10 = 4 1 1 2 1 0 0 0.
   COMPUTE phase=value10.
   END REPEAT.   
ELSE IF (Event=11).
   DO REPEAT phase=phase1 to phase8
      /value11 = 4 1 1 2 2 0 0 0.
   COMPUTE phase=value11.
   END REPEAT.      
ELSE IF (Event=12).
   DO REPEAT phase=phase1 to phase8
      /value12 = 4 1 1 2 2 1 0 0.
   COMPUTE phase=value12.
   END REPEAT.         
ELSE IF (Event=13).
   DO REPEAT phase=phase1 to phase8
      /value13 = 4 1 1 2 2 1 1 0.
   COMPUTE phase=value13.
   END REPEAT.
ELSE IF (Event=14).
   DO REPEAT phase=phase1 to phase8
      /value14 = 4 1 1 2 2 1 2 0.
   COMPUTE phase=value14.
   END REPEAT.   
ELSE IF (Event=15).
   DO REPEAT phase=phase1 to phase8
      /value15 = 4 1 1 2 2 1 2 1.
   COMPUTE phase=value15.
   END REPEAT.    
ELSE IF (Event=16).
   DO REPEAT phase=phase1 to phase8
      /value16 = 4 1 1 2 2 1 2 2.
   COMPUTE phase=value16.
   END REPEAT.     
ELSE IF (Event=17).
   DO REPEAT phase=phase1 to phase8
      /value17 = 4 1 1 2 2 1 2 3.
   COMPUTE phase=value17.
   END REPEAT.     
ELSE IF (Event=18).
   DO REPEAT phase=phase1 to phase8
      /value18 = 4 1 1 2 2 1 2 4.
   COMPUTE phase=value18.
   END REPEAT.         
END IF.
EXECUTE.

*******************************************************************************************.
******                       Multilevel Models                                     ********.
*******************************************************************************************.

DATASET ACTIVATE example_stacked.

* This takes a very long time to estimate in SPSS.
ECHO "Saturated Means, Unstructured Variance Model on Comfort at 18 Events".
ECHO "Used to make Figure 1".
MIXED comfort BY PersonID event
 /METHOD   = ML
 /PRINT    = SOLUTION TESTCOV R
 /FIXED    = event
 /REPEATED = event | SUBJECT(PersonID) COVTYPE(UN)
 /EMMEANS  = TABLES(event).

ECHO "Supplemental Material Equation 2: Univariate RM ANOVA Model on Comfort at 18 events".
MIXED comfort BY PersonID event sample 
 /METHOD   = REML
 /PRINT    = SOLUTION TESTCOV
 /FIXED    = event sample event*sample
 /REPEATED = event | SUBJECT(PersonID) COVTYPE(CS)
 /MISSING  = INCLUDE
 /EMMEANS  = TABLES(event) TABLES(sample) TABLES(event*sample).

ECHO "Supplemental Material Equation 3: Empty Means, Random Intercept Model".
MIXED comfort BY PersonID event 
 /METHOD   = ML
 /PRINT    = SOLUTION TESTCOV
 /RANDOM   = INTERCEPT | SUBJECT (PersonID) COVTYPE(UN)
 /REPEATED = event | SUBJECT(PersonID) COVTYPE(ID)
 /MISSING  = INCLUDE.

ECHO "Supplemental Material Equation 4: Random Intercept, Fixed Piecewise Slopes Model".
MIXED comfort BY PersonID
              WITH phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 
 /METHOD   = ML
 /PRINT    = SOLUTION TESTCOV
 /FIXED    = phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 phase8*phase8
 /RANDOM   = INTERCEPT | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = event | SUBJECT(PersonID) COVTYPE(ID)
 /MISSING  = INCLUDE.

ECHO "Supplemental Material Equation 5: Random Piecewise Slopes Model".
MIXED comfort BY PersonID
              WITH phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 
 /METHOD   = ML
 /PRINT    = SOLUTION TESTCOV G
 /FIXED    = phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 phase8*phase8
 /RANDOM   = INTERCEPT phase1 phase2 phase3 phase4 phase5 phase6 phase8 
                   | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = event | SUBJECT(PersonID) COVTYPE(ID)
 /MISSING = INCLUDE.

* Note:  This is for improving model fit, and refers to Supplemental Material Equation 6.
* Variables needed for revised random slope model.

DATASET ACTIVATE example_stacked.
* To allow mean increment at event2.
COMPUTE Event02=0.
IF (Event=2) Event02=1.
* To allow different residual variances.
COMPUTE resAup=0.
IF ((Event EQ 9) OR (Event EQ 12) OR (Event EQ 15) OR (Event EQ 16) 
OR (Event EQ 17) OR (Event EQ 18)) resAup=1.
* Residual variance differs to allow random intercept.
IF ((Event EQ 10) OR (Event EQ 11) OR (Event EQ 13) OR (Event EQ 14)) resAup=2. 
* To allow extra residual covariance for 13-14.
COMPUTE rand1314=0.
IF ((Event EQ 13) OR (Event EQ 14)) rand1314=1.
* To allow extra residual covariance for 10-11.
COMPUTE rand1011=0.
IF ((Event EQ 10) OR (Event EQ 11)) rand1011=1.
EXECUTE.

ECHO "Supplemental Material Equation 6: Revised Random Piecewise Slopes Model".
ECHO "Residual covariances via random intercepts do not match Mplus, but are close".
MIXED comfort BY   PersonID resAup 
              WITH phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 event02
                   rand1314 rand1011
 /METHOD   = ML
 /PRINT    = SOLUTION TESTCOV G
 /FIXED    = phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 phase8*phase8 event02
 /RANDOM   = INTERCEPT phase1 phase2 phase3 phase4 phase5 phase6 phase8
                    | SUBJECT(PersonID) COVTYPE(UN)
 /RANDOM   = rand1314 rand1011 | SUBJECT(PersonID) COVTYPE(VC)
 /REPEATED = resAup | SUBJECT(PersonID*event) COVTYPE(DIAG)
 /MISSING  = INCLUDE
 /TEST     = "Slope difference between phase 1 and phase 2" phase1 -1 phase2 1.

ECHO "Supplemental Material Equation 7 Sample Predicting Random Piecewise Slopes".
ECHO "Residual covariances via random intercepts do not match Mplus, but are close".
ECHO "U.S. sample (reference group=0), Philippines sample (comparison group=1)".
ECHO "Stopping point is not included".
MIXED comfort BY   PersonID resAup 
              WITH phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 event02 sample
                   rand1314 rand1011 
 /METHOD   = ML
 /PRINT    = SOLUTION TESTCOV G
 /FIXED    = phase1 phase2 phase3 phase4 phase5 phase6 phase7 phase8 phase8*phase8 event02
             sample sample*phase1 sample*phase2 sample*phase3 sample*phase4 sample*phase5 
             sample*phase6 sample*phase8
 /RANDOM   = INTERCEPT phase1 phase2 phase3 phase4 phase5 phase6 phase8 
                    | SUBJECT(PersonID) COVTYPE(UN)
 /RANDOM   = rand1314 rand1011 | SUBJECT(PersonID) COVTYPE(VC)
 /REPEATED = resAup | SUBJECT(PersonID*event) COVTYPE(DIAG)
 /MISSING  = INCLUDE
 /TEST     = "PH Intercept"     intercept 1 sample 1
 /TEST     = "PH phase 1 slope" phase1 1 sample*phase1 1
 /TEST     = "PH phase 2 slope" phase2 1 sample*phase2 1
 /TEST     = "PH phase 3 slope" phase3 1 sample*phase3 1
 /TEST     = "PH phase 4 slope" phase4 1 sample*phase4 1
 /TEST     = "PH phase 5 slope" phase5 1 sample*phase5 1
 /TEST     = "PH phase 6 slope" phase6 1 sample*phase6 1
 /TEST     = "PH phase 8 slope" phase8 1 sample*phase8 1.


